==> nextcloud-app-notes-3.1.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/sv.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Anteckningar",
    "The last viewed note cannot be accessed. " : "Den senast visade anteckningen kan inte nås.",
    "The notes folder is not accessible: %s" : "Anteckningsmappen är inte tillgänglig: %s",
    "New note" : "Ny anteckning",
    "Encryption Error" : "Krypteringsfel",
    "Error" : "Fel",
    "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
    "Settings" : "Inställningar",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
    "Folder to store your notes" : "Mapp för att spara dina anteckningar",
    "path to notes" : "sökväg till anteckningar",
    "File extension for new notes" : "Filtillägg för nya anteckningar",
    "All notes" : "Alla anteckningar",
    "Categories" : "Kategorier",
    "No search result for “{search}” in {category}" : "Inget sökresultat för “{search}” i {category}",
    "No search result for “{search}”" : "Inget sökresultat för “{search}”",
    "Loading …" : "Laddar ...",
    "Search result for “{search}” in {category}" : "Sökresultat för “{search}” i {category}",
    "Search result for “{search}”" : "Sökresultat för “{search}”",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "This week" : "Denna vecka",
    "Last week" : "Förra veckan",
    "This month" : "Denna månad",
    "Last month" : "Förra månaden",
    "Delete note" : "Radera anteckning",
    "Deleted {title}" : "Raderad {title}",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Empty note" : "Tom anteckning",
    "Write …" : "Skriv ...",
    "Details" : "Detaljer",
    "Preview" : "Förhandsvisa",
    "Edit" : "Redigera",
    "Exit full screen" : "Avsluta fullskärm",
    "Full screen" : "Fullskärm",
    "Save failed. Click to retry." : "Kunde inte spara. Klicka för att försöka igen.",
    "Set category" : "Ange kategori",
    "Category" : "Kategori",
    "Uncategorized" : "Okategoriserad",
    "Click here to save manually" : "Klicka här för att spara manuellt.",
    "Saving failed!" : "Misslyckades att spara!",
    "Last modified: {date}" : "Senast ändrad: {date}",
    "Note has unsaved changes" : "Note har osparade ändringar",
    "Subcategory" : "Underkategori",
    "_%n word_::_%n words_" : ["%n ord","%n ord"],
    "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan några distraktioner.",
    "Use Markdown markups to style your text." : "Använd Markdown för att formatera din text.",
    "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installera appen för din mobiltelefon för att få åtkomst till dina anteckningar överallt.",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Böja skriva en anteckning genom att klicka på “{newnote}” i menyn.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Du kan skapa underkategorier genom att använda “/” som avgränsare mellan överordnad kategori och underkategori, t.ex. “{parent}/{sub}”.",
    "Please chose a valid path in {label} (bottom left corner)." : "Välj en giltig sökväg i {label} (nedre vänstra hörnet).",
    "See JavaScript console for details." : "Se JavaScript-konsolen för mer information.",
    "Saving the note has failed due to insufficient storage." : "Kunde inte spara anteckningen på grund av otillräckligt lagringsutrymme.",
    "Updating settings has failed." : "Kunde inte uppdatera inställningar. ",
    "Fetching notes has failed." : "Kunde inte hämta anteckningar.",
    "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
    "Creating new note has failed." : "Kunde inte skapa ny anteckning.",
    "Updating note {id} has failed." : "Uppdatering av anteckning {id} misslyckades.",
    "Deleting note {id} has failed." : "Radering av anteckning {id} misslyckades.",
    "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
    "Updating the note's category has failed. Is the target directory writable?" : "Uppdatering av anteckningens kategori misslyckades. Är målmappen skrivbar?",
    "Updating the category for note {id} has failed." : "Uppdatering av kategori för anteckning {id} misslyckades.",
    "Development Mode" : "Utvecklingsläge",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Det ser ut som att anteckningsappen installerades från en utvecklingskälla. Installera från den officiella <a href=\"%1$s\">Nextcloud App-Store</a> istället. Om du vill bygga Notes-appen själv, följ <a href=\"%2$s\">utvecklarinstruktionerna</a>."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-notes-3.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/sv.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Anteckningar",
    "The last viewed note cannot be accessed. " : "Den senast visade anteckningen kan inte nås.",
    "The notes folder is not accessible: %s" : "Anteckningsmappen är inte tillgänglig: %s",
    "Error" : "Fel",
    "New note" : "Ny anteckning",
    "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
    "Settings" : "Inställningar",
    "Deleted {title}" : "Raderad {title}",
    "Deleted {number} notes" : "Raderade {number} anteckningar",
    "Undo Delete" : "Ångra radering",
    "Please chose a valid path in {label} (bottom left corner)." : "Välj en giltig sökväg i {label} (nedre vänstra hörnet).",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
    "Folder to store your notes" : "Mapp för att spara dina anteckningar",
    "path to notes" : "sökväg till anteckningar",
    "File extension for new notes" : "Filtillägg för nya anteckningar",
    "All notes" : "Alla anteckningar",
    "Categories" : "Kategorier",
    "No search result for “{search}” in {category}" : "Inget sökresultat för “{search}” i {category}",
    "No search result for “{search}”" : "Inget sökresultat för “{search}”",
    "Loading …" : "Läser in ...",
    "Search result for “{search}” in {category}" : "Sökresultat för “{search}” i {category}",
    "Search result for “{search}”" : "Sökresultat för “{search}”",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "This week" : "Denna vecka",
    "Last week" : "Förra veckan",
    "This month" : "Denna månad",
    "Last month" : "Förra månaden",
    "Rename" : "Byt namn",
    "Note's title" : "Anteckningens titel",
    "Delete note" : "Radera anteckning",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "Error during preparing note for deletion." : "Fel vid förberedelse av anteckning för radering.",
    "Empty note" : "Tom anteckning",
    "Write …" : "Skriv ...",
    "Details" : "Detaljer",
    "Preview" : "Förhandsvisa",
    "Edit" : "Redigera",
    "Exit full screen" : "Avsluta fullskärm",
    "Full screen" : "Fullskärm",
    "Save failed. Click to retry." : "Kunde inte spara. Klicka för att försöka igen.",
    "Set category" : "Ange kategori",
    "Category" : "Kategori",
    "Uncategorized" : "Okategoriserad",
    "Click here to save manually" : "Klicka här för att spara manuellt.",
    "Saving failed!" : "Misslyckades att spara!",
    "Last modified: {date}" : "Senast ändrad: {date}",
    "Note has unsaved changes" : "Note har osparade ändringar",
    "Subcategory" : "Underkategori",
    "_%n word_::_%n words_" : ["%n ord","%n ord"],
    "Write down your thoughts without any distractions." : "Skriv ner dina tankar utan några distraktioner.",
    "Use Markdown markups to style your text." : "Använd Markdown för att formatera din text.",
    "Organize your notes in categories." : "Organisera dina anteckningar i kategorier.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Installera appen för din mobiltelefon för att få åtkomst till dina anteckningar överallt.",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Böja skriva en anteckning genom att klicka på “{newnote}” i menyn.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Du kan skapa underkategorier genom att använda “/” som avgränsare mellan överordnad kategori och underkategori, t.ex. “{parent}/{sub}”.",
    "See JavaScript console and server log for details." : "Se JavaScript-konsol och serverlogg för detaljer.",
    "Saving the note has failed due to insufficient storage." : "Kunde inte spara anteckningen på grund av otillräckligt lagringsutrymme.",
    "Updating settings has failed." : "Kunde inte uppdatera inställningar. ",
    "Fetching notes has failed." : "Kunde inte hämta anteckningar.",
    "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
    "Renaming note {id} has failed." : "Namnbyte av anteckning {id} misslyckades.",
    "Creating new note has failed." : "Kunde inte skapa ny anteckning.",
    "Updating note {id} has failed." : "Uppdatering av anteckning {id} misslyckades.",
    "Undo delete has failed for note {title}." : "Ångra radering misslyckades för anteckning {title}.",
    "Deleting note {id} has failed." : "Radering av anteckning {id} misslyckades.",
    "Toggling favorite for note {id} has failed." : "Växling av favorit för anteckning {id} misslyckades.",
    "Updating the note's category has failed. Is the target directory writable?" : "Uppdatering av anteckningens kategori misslyckades. Är målmappen skrivbar?",
    "Updating the category for note {id} has failed." : "Uppdatering av kategori för anteckning {id} misslyckades.",
    "Development Mode" : "Utvecklingsläge",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Det ser ut som att anteckningsappen installerades från en utvecklingskälla. Installera från den officiella <a href=\"%1$s\">Nextcloud App-Store</a> istället. Om du vill bygga Notes-appen själv, följ <a href=\"%2$s\">utvecklarinstruktionerna</a>."
},
"nplurals=2; plural=(n != 1);");
